@@ -106,8 +106,9 @@ org.mozdev.compactHeader.pane = function() {
 
   var coheFirstTime = true;
   var headerFirstTime = true;
-  
+
   var pressMores = null;
+  var gMoreTooltip = "";
 
   function coheOutputSubject(headerEntry, headerValue) {
     var subjectBox;
@@ -136,7 +137,8 @@ org.mozdev.compactHeader.pane = function() {
 
     let moreButton = document.getAnonymousElementByAttribute(document.getElementById("CompactHeader_collapsed2LtoCcBccBox"),
         "anonid", "more");
-    let moreTooltip = moreButton.getAttribute("tooltiptext");
+    let moreTooltip = gMoreTooltip;
+//    let moreTooltip = moreButton.getAttribute("tooltiptext");
 
     var msgHeaderParser = Components.classes["@mozilla.org/messenger/headerparser;1"]
                                     .getService(Components.interfaces.nsIMsgHeaderParser);
@@ -177,7 +179,9 @@ org.mozdev.compactHeader.pane = function() {
       }
       index++;
     }
+    org.mozdev.compactHeader.debug.log("tooltiptext: " + moreTooltip);
     moreButton.setAttribute("tooltiptext", moreTooltip);
+    gMoreTooltip = moreTooltip;
 
     if (headerEntry.useToggle && (typeof headerEntry.enclosingBox.buildViews == 'function'))
       headerEntry.enclosingBox.buildViews();
@@ -241,7 +245,7 @@ org.mozdev.compactHeader.pane = function() {
     }
     pressMores = null;
   }
-  
+
   pub.coheOnLoadMsgHeaderPane = function() {
     org.mozdev.compactHeader.debug.log("coheOnLoadMsgHeaderPane start");
 
@@ -292,10 +296,26 @@ org.mozdev.compactHeader.pane = function() {
       if (collapsed2LtoCcBccBox) {
         let updateEmailAddressNodeFunction = collapsed2LtoCcBccBox.updateEmailAddressNode;
         function updateEmailAddressNodeNew(aEmailNode, aAddress) {
-          updateEmailAddressNode(aEmailNode, aAddress)
+          try {
+            updateEmailAddressNodeFunction(aEmailNode, aAddress);
+          }
+          catch(e) {
+            org.mozdev.compactHeader.debug.log("got execption " + e +
+              " from updateEmailAddressNode");
+          }
           aEmailNode.setAttribute("addressType", aAddress.addressType);
         }
         collapsed2LtoCcBccBox.updateEmailAddressNode = updateEmailAddressNodeNew;
+        if (typeof collapsed2LtoCcBccBox.setNMoreTooltiptext == 'function') {
+          // remove setNMoreTooltiptext because we have our own function
+          collapsed2LtoCcBccBox.setNMoreTooltiptext = function() {
+            let moreButton = document.getAnonymousElementByAttribute(document.getElementById("CompactHeader_collapsed2LtoCcBccBox"),
+              "anonid", "more");
+            if (moreButton) {
+              moreButton.setAttribute("tooltiptext", gMoreTooltip);
+            }
+          };
+        }
       }
     }
 
@@ -541,6 +561,7 @@ org.mozdev.compactHeader.pane = function() {
     let moreButton = document.getAnonymousElementByAttribute(document.getElementById("CompactHeader_collapsed2LtoCcBccBox"),
         "anonid", "more");
     moreButton.setAttribute("tooltiptext", "");
+    gMoreTooltip = "";
 
     // iterate over each header we received and see if we have a matching entry
     // in each header view table...
@@ -682,6 +703,8 @@ org.mozdev.compactHeader.pane = function() {
           ||(aData == "toolbox.position")
           ) {
         preferencesUpdate();
+      } else if (aData == "header.doubleclick") {
+        setDblClickHeaderEventHandler();
       }
 
       org.mozdev.compactHeader.debug.log("prefObserver stop");
@@ -781,19 +804,92 @@ org.mozdev.compactHeader.pane = function() {
     }
 
     var multiMessage = document.getElementById("multimessage");
-    if (multiMessage){
+    if (multiMessage) {
       org.mozdev.compactHeader.debug.log("multiMessage " + multiMessage);
       multiMessage.addEventListener("DOMContentLoaded", multiMessageLoaded, true);
     }
 
+    addMessagePaneBoxFocusHandler();
+    setDblClickHeaderEventHandler();
+    org.mozdev.compactHeader.debug.log("coheInitializeOverlay stop");
+  };
+
+  function addMessagePaneBoxFocusHandler() {
+    let messagepanebox = document.getElementById("messagepanebox");
+    if (messagepanebox) {
+      messagepanebox.addEventListener("focus", messagePaneBoxFocus, true);
+      messagepanebox.addEventListener("blur", messagePaneBoxBlur, true);
+    }
+  }
+
+  var msgHeaderViewBackground;
+
+  function messagePaneBoxFocus(event) {
+    org.mozdev.compactHeader.debug.log("messagePaneBoxFocus start");
+    let msgHeaderView = document.getElementById("msgHeaderView");
+    let wintype = document.documentElement.getAttribute("windowtype");
+//    let tabmail = document.getElementById("tabmail");
+    if (cohePrefBranch.getBoolPref("header.darkenonfocus") &&
+        msgHeaderView && wintype && wintype == "mail:3pane" ) {
+//          && tabmail && tabmail.tabContainer.selectedIndex == 0) {
+      org.mozdev.compactHeader.debug.log("background: " +
+          msgHeaderViewBackground);
+      if (typeof msgHeaderViewBackground === "undefined") {
+        var style =
+          document.defaultView.getComputedStyle(msgHeaderView, null);
+        msgHeaderViewBackground = style.getPropertyValue("background-color");
+      }
+      org.mozdev.compactHeader.debug.log("style: " + style);
+      org.mozdev.compactHeader.debug.log("background: " +
+        msgHeaderViewBackground);
+      let newColor = darkenColor(msgHeaderViewBackground);
+      msgHeaderView.style.backgroundColor = newColor;
+      //       msgHeaderView.setAttribute('style', 'background-color:darkblue;');
+    }
+    org.mozdev.compactHeader.debug.log("messagePaneBoxFocus stop");
+  }
+
+  function darkenColor(color) {
+    var digits = /(.*?)rgb\((\d+), (\d+), (\d+)\)/.exec(color);
+
+    var red = parseInt(digits[2]);
+    var green = parseInt(digits[3]);
+    var blue = parseInt(digits[4]);
+
+    let factor = 0.9;
+
+    red = red * factor;
+    green = green * factor;
+    blue = blue * factor;
+
+    var rgb = blue | (green << 8) | (red << 16);
+    return digits[1] + '#' + rgb.toString(16);
+}
+
+  function messagePaneBoxBlur(event) {
+    let msgHeaderView = document.getElementById("msgHeaderView");
+    let wintype = document.documentElement.getAttribute("windowtype");
+    let tabmail = document.getElementById("tabmail");
+//    if (msgHeaderView && wintype && wintype == "mail:3pane" &&
+//        tabmail && tabmail.tabContainer.selectedIndex == 0) {
+    if (msgHeaderView) {
+      if (!(typeof msgHeaderViewBackground === "undefined")) {
+        msgHeaderView.style.backgroundColor = msgHeaderViewBackground;
+        msgHeaderViewBackground = undefined;
+      }
+    }
+  }
+
+  function setDblClickHeaderEventHandler() {
     var msgHeaderViewDeck = document.getElementById("msgHeaderViewDeck");
     if (msgHeaderViewDeck){
       org.mozdev.compactHeader.debug.log("msgHeaderViewDeck " + msgHeaderViewDeck);
-      msgHeaderViewDeck.addEventListener("dblclick", org.mozdev.compactHeader.pane.coheToggleHeaderView, true);
+      if (cohePrefBranch.getBoolPref("header.doubleclick"))
+        msgHeaderViewDeck.addEventListener("dblclick", org.mozdev.compactHeader.pane.coheToggleHeaderView, true);
+      else
+        msgHeaderViewDeck.removeEventListener("dblclick", org.mozdev.compactHeader.pane.coheToggleHeaderView, true);
     }
-
-    org.mozdev.compactHeader.debug.log("coheInitializeOverlay stop");
-  };
+  }
 
   function multiMessageLoaded() {
     org.mozdev.compactHeader.debug.log("multiMessageLoaded start");
