@@ -60,6 +60,17 @@ org.mozdev.compactHeader.toolbar = function() {
     {pos:"none",  id:"",                                   orient:""},
   ];
 
+  let gOtherMenuCommands = {
+      otherActionsOpenConversation: "cmd_openConversation",
+      otherActionsOpenInNewWindow:  "cmd_openMessage",
+      otherActionsOpenInNewTab:     "cmd_openMessage",
+      viewSourceMenuItem:           "cmd_viewPageSource",
+      markAsReadMenuItem:           "cmd_markAsRead",
+      markAsUnreadMenuItem:         "cmd_markAsUnread",
+      saveAsMenuItem:               "cmd_saveAsFile",
+      otherActionsPrint:            "cmd_print"
+    };
+
   pub.cannotMoveToolbox = function() {
     var appInfo = Components.classes["@mozilla.org/xre/app-info;1"]
       .getService(Components.interfaces.nsIXULAppInfo);
@@ -164,16 +175,36 @@ org.mozdev.compactHeader.toolbar = function() {
     var newParent = document.getElementById(target) ||
         document.getElementById("header-view-toolbox").palette.getElementsByAttribute("id", target)[0];
 
+    org.mozdev.compactHeader.debug.log("looking for CompactHeader_hdrOtherActionsButton");
+
     if (newParent != null) {
       var myElement;
       myElement= document.getElementById("otherActionsPopup");
       if (myElement) {
         newParent.appendChild(myElement);
+        for (let menu in gOtherMenuCommands) {
+          let menuEl = document.getElementById(menu);
+          org.mozdev.compactHeader.debug.log("command to " + menu);
+          if (menuEl) {
+            org.mozdev.compactHeader.debug.log("fillToolboxPalette add command to " + menu + ": " + gOtherMenuCommands[menu]);
+            menuEl.setAttribute("command", gOtherMenuCommands[menu]);
+          }
+        }
       }
     }
     org.mozdev.compactHeader.debug.log("fillToolboxPalette stop");
   };
 
+  pub.showOtherActionButtonMenu = function() {
+    org.mozdev.compactHeader.debug.log("showOtherActionButtonMenu start");
+    onShowOtherActionsPopup();
+    InitMessageMark();
+    for (let menu in gOtherMenuCommands) {
+      goUpdateCommand(gOtherMenuCommands[menu]);
+    }
+    org.mozdev.compactHeader.debug.log("showOtherActionButtonMenu stop");
+  }
+
   pub.setButtonStyle = function() {
     org.mozdev.compactHeader.debug.log("setButtonStyle start");
     var hdrToolbar = document.getElementById("header-view-toolbar");
@@ -535,7 +566,7 @@ org.mozdev.compactHeader.toolbar = function() {
 
     if ((currentToolboxPosition == targetPos) &&
         (currentToolboxType == targetType) &&
-        (currentHeaderViewMode == aHeaderViewMode) && 
+        (currentHeaderViewMode == aHeaderViewMode) &&
         (targetType == "single")) {
       org.mozdev.compactHeader.debug.log("curPos: " + currentToolboxPosition + " targetPos: " + targetPos);
       org.mozdev.compactHeader.debug.log("curType: " + currentToolboxType + " targetType: " + targetType);
@@ -551,7 +582,7 @@ org.mozdev.compactHeader.toolbar = function() {
     currentHeaderViewMode = aHeaderViewMode;
 
     org.mozdev.compactHeader.debug.log("setCurrentToolboxPosition 3");
-    
+
     if (multiMessage){
       org.mozdev.compactHeader.debug.log("multiMessage " + multiMessage);
       try {
